@@ -5,6 +5,7 @@ import re
 import os
 import numpy as np
 import matplotlib.pyplot as plt
+import unidecode
 from sklearn.preprocessing import StandardScaler
 from math import pi
 from fpl_analytics.FPLUnderStats import GetStats
@@ -265,14 +266,20 @@ class FPLAnalytics:
 
         return combPlayerdetails
     
+    def convertSpecialChar(wrd):
+        return unidecode.unidecode(wrd)
+
     def findPlayer(self, pattern):
+        
         players = [p.strip() for p in pattern.split(' ')]
         stats = self.getPlayerSummary()
+        stats['web_name_decode'] = stats[['web_name']].apply(lambda x: convertSpecialChar(x['web_name']), axis = 1)
+        
         result = pd.DataFrame()
         for p in players:
-            df = stats[stats['web_name'].str.match(p, flags=re.IGNORECASE)]
+            df = stats[stats['web_name_decode'].str.match(p, flags=re.IGNORECASE)]
             if df.shape[0] == 0:
-                df = stats[stats['web_name'].str.contains(p, flags=re.IGNORECASE, regex=True)]
+                df = stats[stats['web_name_decode'].str.contains(p, flags=re.IGNORECASE, regex=True)]
             result = pd.concat([result, df])
         return result
 
@@ -416,4 +423,3 @@ class FPLAnalytics:
                 plt.close(fig)
         
         return players
-
